# eCrime.Ch Client
A CLI tool to interact with the eCrime.ch ( https://ecrime.ch/ ) API.
API Documentation: https://ecrime.ch/api/docs/


## Installation

To install this package from source, run:

```
git clone https://github.com/silascutler/pyecrime.git
cd pyecrime
pip install .
```

